#!/usr/bin/python
# -*- coding: utf-8 -*-


"""

this file will handle all the function related to credit card...
some part of this file inspired from https://github.com/eye9poob/python/blob/master/credit-card-numbers-generator.py

"""
import copy
try:
  from production_config import PRODUCTION
except:
  from .production_config import PRODUCTION
if PRODUCTION:
  from .utils import get_random_generator
else:
  from utils import get_random_generator


  
class CreditCardGenerator(object):

  def __init__(self,
    size: int,
    how_many: int,):
    super().__init__()
    self.size = size
    self.random_generator = get_random_generator()
    self.how_many = how_many

  @staticmethod
  def card_comp_number(prefix, size, random_generator):
    """
    prefix: type of card prefixs
    size: card number lenght
    """

    # make card numbers
    cc_number = prefix

    while len(prefix) < (size-1):
      digit = str(random_generator.choice(range(0, 10)))
      cc_number.append(digit)

    sum = 0
    pos = 0

    reversed_cc_number = []
    reversed_cc_number.extend(cc_number)
    reversed_cc_number.reverse()
    
    while pos < size - 1:

      odd = int(reversed_cc_number[pos]) * 2

      if odd > 9:
        odd -= 9

      sum += odd

      if pos != (size-2):
          sum += int(reversed_cc_number[pos + 1])
        
      pos += 2

    check_digit = ((sum / 10 +1) * 10 - sum) % 10

    cc_number.append(str(check_digit))
    
    return  ''.join(cc_number) 


  @staticmethod
  def convert_number_into_format(card_number: str):
    """
    this function will convert numbers into card formates
    card_number: int = number of card
    """
    final_str = ''
    counter = 0
    for i in range(4, len(card_number)+5, 4):
      final_str += ' ' + card_number[counter:i]
      counter+=4
    return final_str[1:-1]


  def return_card_number(self, prefix_ls):
    """
    This function will return perticular cradit card number
    """

    cc_number = copy.copy(self.random_generator.choice(prefix_ls))
    generated_num =self.card_comp_number(cc_number, self.size, self.random_generator)
    num = generated_num.split('.')[0]

    if len(num)%4 != 0:
      return "message: kindly use 16 lenght"
    
    return self.convert_number_into_format(num)








# import psycopg2
# from psycopg2 import OperationalError
# from pydantic import BaseModel, Field
# from json import load as json_load
# import pyodbc


# try:
#   from production_config import PRODUCTION
# except:
#   from .production_config import PRODUCTION

  
# if PRODUCTION:
#     from .constants import MARIADB_EXCLUDED_DBS, PII_TABLE_SQL_QUERY, INSERT_QUERY_MARIADB
#     from .utils import is_json_path_valid
# else:
#     from constants import MARIADB_EXCLUDED_DBS, PII_TABLE_SQL_QUERY, INSERT_QUERY_MARIADB
#     from utils import is_json_path_valid


# def create_psql_connection_string(user: str, db_name: str,
#                                   host: str, password: str):
#     """
#     this function is responsible for creating the psql connection string
#      username: str = username of server
#      password: str = password of server
#      host: str = name of server
#      db_name: str = name of database that want to scan
#     """
#     connection_string = (f"host={host} "
#                          f"user={user} dbname={db_name} "
#                          f"password={password} sslmode=require")
#     return connection_string


# def get_psql_connection(connection_string: str):
#     """
#     this function is responsible for creating
#      connection between app and psql db
#     """
#     # try:
#     print(connection_string)
#     connection = psycopg2.connect(connection_string)
#     connection.autocommit = True
#     return connection
#     # except OperationalError as e:
#     #     return f" message :  //{e}"



# class PsqlConfig(BaseModel):
#     """
#     Have some validation
#     """
#     user: str = Field(...)
#     password: str = Field(...)
#     db_name: str = Field(...)
#     host: str = Field(...)


# def get_psql_config_data_from_json(file_path: str):

#     if is_json_path_valid(file_path):
#         f = open(file_path)
#         data = json_load(f)
#         f.close()
#         try:
#             PsqlConfig(**data)
#         except Exception as e:
#             return f"message: {e}"
#         return data
        
#     else:
#         return "message: kindly enter the valid path of json"



# def enter_pii_data_in_psql(file_path: str, pii_data: list):
#     config_data = get_psql_config_data_from_json(file_path)
#     if type(config_data) == dict:
#         conn_str  = create_psql_connection_string(**config_data)
#         conn = get_psql_connection(conn_str)
#         cursor = conn.cursor()
#         if config_data['db_name'] in MARIADB_EXCLUDED_DBS:
#             cursor.execute("Create Database test;")
#             print('test database has been created...')
#             cursor.execute("Use test;")
#         try:
#             cursor.execute(PII_TABLE_SQL_QUERY)
#         except:
#             pass

#         try:
#             cursor.executemany(INSERT_QUERY_MARIADB, pii_data)
#             cursor.execute("SELECT * from PII;")
#             print(cursor.fetchall())
#             cursor.close()
#             conn.close()
#         except Exception as e:
#             return f"message : {str(e)}"
        
#         return True

#     else:
#         return config_data

# def get_odbc_string(server: str, database: str, username: str,
#                     password: str):
#     """
#     this function will return odbc connection string
#     server_name: str = name of the server
#     database: str = name of the database
#     username: str = username of the database
#     password: str = password of the database
#     driver: str  = version of oracle driver
#     """
#     pwd = f'{password}'
#     driver = '{ODBC Driver 17 for SQL Server}'
#     connection_string = (f'Driver={driver};Server=tcp:{server};'
#                          f'Database={database};Uid={username};Pwd={pwd};'
#                          f'Encrypt=yes;TrustServerCertificate=yes;Connection Timeout=60;')
#     return connection_string

# # def get_sql_db_client(connection_string: str):
# #   """
# #   This function will return the sql db client
# #   connection_string: str
# #   """
# #   # try:
# #   conn: pyodbc.Connection = pyodbc.connect(connection_string)
# #   cursor: pyodbc.Cursor = conn.cursor()
# #   # except Exception as e:
# #   #     return e
# #   return cursor

# # f = open("/Users/deepak9636/Drive/msec/pii-generator-develop/config_example/azure_sql.json")
# # import json
# # d = json.load(f)
# # f.close()
# # print(d)
# # cs = get_odbc_string(**d)
# # print(cs)
# # con = get_sql_db_client(cs)
# # print(con)


import pathlib
from setuptools import setup
from os import  path
# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()
print(HERE)
requirementPath = str(HERE / "requirements.txt")
print(requirementPath)
install_requires = [] # Here we'll get: ["gunicorn", "docutils>=0.3", "lxml==0.5a7"]
print(path.isfile(requirementPath))
if path.isfile(requirementPath):
    print(requirementPath)
    with open(requirementPath) as f:
        install_requires = f.read().splitlines()
# This call to setup() does all the work
print(install_requires)
setup(
    name="pii-data-generator",
    version="1.0.5",
    description="It generats the dummy 'Personally identifiable information' data",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/AvinashRajPurohit/pii-data-generator",
    author="Deepak Rajpurohit",
    author_email="deepakrajpurohit945@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",

    ],
    packages=["pii_generator"],
    include_package_data=True,
    entry_points = {
        'console_scripts': ['pii = pii_generator.command_line:main'],
    },
    install_requires=install_requires,

)